@@ -45,7 +45,7 @@ class BasicTestCase(unittest.TestCase):
     _numKeys      = 1002    # PRIVATE.  NOTE: must be an even value
 
     import sys
-    if sys.version_info[:3] < (2, 4, 0):
+    if sys.version_info < (2, 4):
         def assertTrue(self, expr, msg=None):
             self.failUnless(expr,msg=msg)
         def assertFalse(self, expr, msg=None):
@@ -74,14 +74,13 @@ class BasicTestCase(unittest.TestCase):
         # create and open the DB
         self.d = db.DB(self.env)
         if not self.useEnv :
-            if db.version() >= (4, 2) :
-                self.d.set_cachesize(*self.cachesize)
-                cachesize = self.d.get_cachesize()
-                self.assertEqual(cachesize[0], self.cachesize[0])
-                self.assertEqual(cachesize[2], self.cachesize[2])
-                # Berkeley DB expands the cache 25% accounting overhead,
-                # if the cache is small.
-                self.assertEqual(125, int(100.0*cachesize[1]/self.cachesize[1]))
+            self.d.set_cachesize(*self.cachesize)
+            cachesize = self.d.get_cachesize()
+            self.assertEqual(cachesize[0], self.cachesize[0])
+            self.assertEqual(cachesize[2], self.cachesize[2])
+            # Berkeley DB expands the cache 25% accounting overhead,
+            # if the cache is small.
+            self.assertEqual(125, int(100.0*cachesize[1]/self.cachesize[1]))
         self.d.set_flags(self.dbsetflags)
         if self.dbname:
             self.d.open(self.filename, self.dbname, self.dbtype,
@@ -153,7 +152,7 @@ class BasicTestCase(unittest.TestCase):
 
         self.assertEqual(d.get('0321'), '0321-0321-0321-0321-0321')
 
-        # By default non-existant keys return None...
+        # By default non-existent keys return None...
         self.assertEqual(d.get('abcd'), None)
 
         # ...but they raise exceptions in other situations.  Call
@@ -162,7 +161,7 @@ class BasicTestCase(unittest.TestCase):
             d.delete('abcd')
         except db.DBNotFoundError, val:
             import sys
-            if sys.version_info[0] < 3 :
+            if sys.version_info < (2, 6) :
                 self.assertEqual(val[0], db.DB_NOTFOUND)
             else :
                 self.assertEqual(val.args[0], db.DB_NOTFOUND)
@@ -185,7 +184,7 @@ class BasicTestCase(unittest.TestCase):
             d.put('abcd', 'this should fail', flags=db.DB_NOOVERWRITE)
         except db.DBKeyExistError, val:
             import sys
-            if sys.version_info[0] < 3 :
+            if sys.version_info < (2, 6) :
                 self.assertEqual(val[0], db.DB_KEYEXIST)
             else :
                 self.assertEqual(val.args[0], db.DB_KEYEXIST)
@@ -339,7 +338,7 @@ class BasicTestCase(unittest.TestCase):
             except db.DBNotFoundError, val:
                 if get_raises_error:
                     import sys
-                    if sys.version_info[0] < 3 :
+                    if sys.version_info < (2, 6) :
                         self.assertEqual(val[0], db.DB_NOTFOUND)
                     else :
                         self.assertEqual(val.args[0], db.DB_NOTFOUND)
@@ -364,7 +363,7 @@ class BasicTestCase(unittest.TestCase):
             except db.DBNotFoundError, val:
                 if get_raises_error:
                     import sys
-                    if sys.version_info[0] < 3 :
+                    if sys.version_info < (2, 6) :
                         self.assertEqual(val[0], db.DB_NOTFOUND)
                     else :
                         self.assertEqual(val.args[0], db.DB_NOTFOUND)
@@ -391,7 +390,7 @@ class BasicTestCase(unittest.TestCase):
             n = c.set('bad key')
         except db.DBNotFoundError, val:
             import sys
-            if sys.version_info[0] < 3 :
+            if sys.version_info < (2, 6) :
                 self.assertEqual(val[0], db.DB_NOTFOUND)
             else :
                 self.assertEqual(val.args[0], db.DB_NOTFOUND)
@@ -399,7 +398,7 @@ class BasicTestCase(unittest.TestCase):
         else:
             if set_raises_error:
                 self.fail("expected exception")
-            if n != None:
+            if n is not None:
                 self.fail("expected None: %r" % (n,))
 
         rec = c.get_both('0404', self.makeData('0404'))
@@ -409,7 +408,7 @@ class BasicTestCase(unittest.TestCase):
             n = c.get_both('0404', 'bad data')
         except db.DBNotFoundError, val:
             import sys
-            if sys.version_info[0] < 3 :
+            if sys.version_info < (2, 6) :
                 self.assertEqual(val[0], db.DB_NOTFOUND)
             else :
                 self.assertEqual(val.args[0], db.DB_NOTFOUND)
@@ -417,7 +416,7 @@ class BasicTestCase(unittest.TestCase):
         else:
             if get_raises_error:
                 self.fail("expected exception")
-            if n != None:
+            if n is not None:
                 self.fail("expected None: %r" % (n,))
 
         if self.d.get_type() == db.DB_BTREE:
@@ -442,7 +441,7 @@ class BasicTestCase(unittest.TestCase):
         except db.DBKeyEmptyError, val:
             if get_raises_error:
                 import sys
-                if sys.version_info[0] < 3 :
+                if sys.version_info < (2, 6) :
                     self.assertEqual(val[0], db.DB_KEYEMPTY)
                 else :
                     self.assertEqual(val.args[0], db.DB_KEYEMPTY)
@@ -488,10 +487,10 @@ class BasicTestCase(unittest.TestCase):
                     print "attempting to use a closed cursor's %s method" % \
                           method
                 # a bug may cause a NULL pointer dereference...
-                apply(getattr(c, method), args)
+                getattr(c, method)(*args)
             except db.DBError, val:
                 import sys
-                if sys.version_info[0] < 3 :
+                if sys.version_info < (2, 6) :
                     self.assertEqual(val[0], 0)
                 else :
                     self.assertEqual(val.args[0], 0)
@@ -612,7 +611,7 @@ class BasicTestCase(unittest.TestCase):
 
         d.put("abcde", "ABCDE");
         num = d.truncate()
-        self.assert_(num >= 1, "truncate returned <= 0 on non-empty database")
+        self.assertTrue(num >= 1, "truncate returned <= 0 on non-empty database")
         num = d.truncate()
         self.assertEqual(num, 0,
                 "truncate on empty DB returned nonzero (%r)" % (num,))
@@ -631,9 +630,9 @@ class BasicTestCase(unittest.TestCase):
     if db.version() >= (4, 6):
         def test08_exists(self) :
             self.d.put("abcde", "ABCDE")
-            self.assert_(self.d.exists("abcde") == True,
+            self.assertTrue(self.d.exists("abcde") == True,
                     "DB->exists() returns wrong value")
-            self.assert_(self.d.exists("x") == False,
+            self.assertTrue(self.d.exists("x") == False,
                     "DB->exists() returns wrong value")
 
     #----------------------------------------
@@ -713,9 +712,14 @@ class BasicHashWithEnvTestCase(BasicWithEnvTestCase):
 
 class BasicTransactionTestCase(BasicTestCase):
     import sys
-    if sys.version_info[:3] < (2, 4, 0):
+    if sys.version_info < (2, 4):
         def assertTrue(self, expr, msg=None):
-            self.failUnless(expr,msg=msg)
+            return self.failUnless(expr,msg=msg)
+
+    if (sys.version_info < (2, 7)) or ((sys.version_info >= (3, 0)) and
+            (sys.version_info < (3, 2))) :
+        def assertIn(self, a, b, msg=None) :
+            return self.assertTrue(a in b, msg=msg)
 
     dbopenflags = db.DB_THREAD | db.DB_AUTO_COMMIT
     useEnv = 1
@@ -773,16 +777,13 @@ class BasicTransactionTestCase(BasicTestCase):
         self.txn.commit()
 
         # flush pending updates
-        try:
-            self.env.txn_checkpoint (0, 0, 0)
-        except db.DBIncompleteError:
-            pass
+        self.env.txn_checkpoint (0, 0, 0)
 
         statDict = self.env.log_stat(0);
-        self.assert_(statDict.has_key('magic'))
-        self.assert_(statDict.has_key('version'))
-        self.assert_(statDict.has_key('cur_file'))
-        self.assert_(statDict.has_key('region_nowait'))
+        self.assertIn('magic', statDict)
+        self.assertIn('version', statDict)
+        self.assertIn('cur_file', statDict)
+        self.assertIn('region_nowait', statDict)
 
         # must have at least one log file present:
         logs = self.env.log_archive(db.DB_ARCH_ABS | db.DB_ARCH_LOG)
@@ -790,9 +791,8 @@ class BasicTransactionTestCase(BasicTestCase):
         for log in logs:
             if verbose:
                 print 'log file: ' + log
-        if db.version() >= (4,2):
-            logs = self.env.log_archive(db.DB_ARCH_REMOVE)
-            self.assertTrue(not logs)
+        logs = self.env.log_archive(db.DB_ARCH_REMOVE)
+        self.assertTrue(not logs)
 
         self.txn = self.env.txn_begin()
 
@@ -804,9 +804,9 @@ class BasicTransactionTestCase(BasicTestCase):
             self.d.put("abcde", "ABCDE", txn=txn)
             txn.commit()
             txn = self.env.txn_begin()
-            self.assert_(self.d.exists("abcde", txn=txn) == True,
+            self.assertTrue(self.d.exists("abcde", txn=txn) == True,
                     "DB->exists() returns wrong value")
-            self.assert_(self.d.exists("x", txn=txn) == False,
+            self.assertTrue(self.d.exists("x", txn=txn) == False,
                     "DB->exists() returns wrong value")
             txn.abort()
 
@@ -821,7 +821,7 @@ class BasicTransactionTestCase(BasicTestCase):
         d.put("abcde", "ABCDE");
         txn = self.env.txn_begin()
         num = d.truncate(txn)
-        self.assert_(num >= 1, "truncate returned <= 0 on non-empty database")
+        self.assertTrue(num >= 1, "truncate returned <= 0 on non-empty database")
         num = d.truncate(txn)
         self.assertEqual(num, 0,
                 "truncate on empty DB returned nonzero (%r)" % (num,))
@@ -873,12 +873,11 @@ class BasicTransactionTestCase(BasicTestCase):
 
     #----------------------------------------
 
-    if db.version() >= (4, 2) :
-        def test_get_tx_max(self) :
-            self.assertEqual(self.env.get_tx_max(), 30)
+    def test_get_tx_max(self) :
+        self.assertEqual(self.env.get_tx_max(), 30)
 
-        def test_get_tx_timestamp(self) :
-            self.assertEqual(self.env.get_tx_timestamp(), self._t)
+    def test_get_tx_timestamp(self) :
+        self.assertEqual(self.env.get_tx_timestamp(), self._t)
 
 
 
@@ -1097,7 +1096,7 @@ class HashMultiDBTestCase(BasicMultiDBTestCase):
 
 class PrivateObject(unittest.TestCase) :
     import sys
-    if sys.version_info[:3] < (2, 4, 0):
+    if sys.version_info < (2, 4):
         def assertTrue(self, expr, msg=None):
             self.failUnless(expr,msg=msg)
 
@@ -1140,7 +1139,7 @@ class DBPrivateObject(PrivateObject) :
 
 class CrashAndBurn(unittest.TestCase) :
     import sys
-    if sys.version_info[:3] < (2, 4, 0):
+    if sys.version_info < (2, 4):
         def assertTrue(self, expr, msg=None):
             self.failUnless(expr,msg=msg)
 
