@@ -7,6 +7,52 @@ import re
 import sys
 import glob
 
+if (sys.version_info[0] < 3) and (sys.version_info >= (2, 6)) :
+    # Silence deprecation warnings during "setup"
+    import warnings
+    warnings.filterwarnings('ignore',
+            message='in 3.x, bsddb has been removed; ' \
+                    'please use the pybsddb project instead',
+            category=DeprecationWarning)
+    warnings.filterwarnings('ignore',
+            message='in 3.x, the bsddb module has been removed; ' \
+                    'please use the pybsddb project instead',
+            category=DeprecationWarning)
+
+    if sys.version_info[:2] == (2, 7) :
+        # We should use "with", but it is not available until Python 2.5.
+        context = warnings.catch_warnings()
+        context.__enter__()
+        try :
+            # Python 2.7.0
+            warnings.filterwarnings('ignore',
+                message='The CObject type is marked Pending Deprecation ' \
+                        'in Python 2.7.  Please use capsule objects instead.',
+                category=PendingDeprecationWarning)
+
+            # Python 2.7.1
+            warnings.filterwarnings('ignore',
+                message='CObject type is not supported in 3.x. ' \
+                        'Please use capsule objects instead.',
+                category=DeprecationWarning)
+
+            try :  # 'bsddb' library could be not available
+                import bsddb  # Import the 2.7 version, that uses CObject
+            except ImportError :
+                pass
+        finally :
+            context.__exit__()
+
+    # setuptools warnings
+    warnings.filterwarnings('ignore',
+            message='tuple parameter unpacking has been removed in 3.x',
+            category=SyntaxWarning)
+    warnings.filterwarnings('ignore',
+            message='the dl module has been removed in Python 3.0; ' \
+                    'use the ctypes module instead',
+            category=DeprecationWarning)
+
+
 try :
   from setuptools import setup, Extension
 except :
@@ -28,6 +74,9 @@ for line in _srcFile.readlines():
     if m:
         VERSION = m.group(1)
         continue
+
+# We close first, to avoid a "ResourceWarning" under Python 3.2
+_srcFile.close()
 del _srcFile
 del _ver_re
 del m
@@ -78,29 +127,30 @@ if os.name == 'posix':
     dblib = 'db'
     incdir = libdir = None
     if not BERKELEYDB_DIR and not BERKELEYDB_LIBDIR and not BERKELEYDB_INCDIR:
-        # NOTE: when updating these, also change the tuples in the for loops below
-        max_db_ver = (4, 8)
-        min_db_ver = (4, 1)
+        # Supported Berkeley DB versions, in order of preference.
+        db_ver_list = ((5, 2), (5, 1), (5, 0),
+                (4, 8), (4, 7), (4, 6), (4, 5), (4, 4), (4, 3), (4, 2))
 
         # construct a list of paths to look for the header file in on
         # top of the normal inc_dirs.
-        db_inc_paths = [
-            '/usr/include/db4',
-            '/usr/local/include/db4',
-            '/opt/sfw/include/db4',
-            '/sw/include/db4',
-            '/usr/include/db3',
-            '/usr/local/include/db3',
-            '/opt/sfw/include/db3',
-            '/sw/include/db3',
-        ]
-        # 4.x minor number specific paths
-        for x in range(max_db_ver[1]+1):
-            db_inc_paths.append('/usr/include/db4%d' % x)
-            db_inc_paths.append('/usr/local/BerkeleyDB.4.%d/include' % x)
-            db_inc_paths.append('/usr/local/include/db4%d' % x)
-            db_inc_paths.append('/pkg/db-4.%d/include' % x)
-            db_inc_paths.append('/opt/db-4.%d/include' % x)
+        db_inc_paths = []
+        db_major = {}  # We can use a SET when we drop Python 2.3 support
+        for major, minor in db_ver_list :
+            if major not in db_major :
+                db_major[major] = None
+                db_inc_paths.extend([
+                    '/usr/include/db%d' % major,
+                    '/usr/local/include/db%d' %major,
+                    '/opt/sfw/include/db%d' %major,
+                    '/sw/include/db%d' %major,
+                    ])
+
+            db_inc_paths.append('/usr/include/db%d%d' % (major, minor))
+            db_inc_paths.append('/usr/local/BerkeleyDB.%d.%d/include' % (major,
+                minor))
+            db_inc_paths.append('/usr/local/include/db%d%d' % (major, minor))
+            db_inc_paths.append('/pkg/db-%d.%d/include' % (major, minor))
+            db_inc_paths.append('/opt/db-%d.%d/include' % (major, minor))
 
         db_ver_inc_map = {}
 
@@ -130,7 +180,7 @@ if os.name == 'posix':
                         db_ver = (db_major, db_minor)
 
                         if ( (db_ver not in db_ver_inc_map) and
-                           (db_ver <= max_db_ver and db_ver >= min_db_ver) ):
+                           (db_ver in db_ver_list) ):
                             # save the include directory with the db.h version
                             # (first occurrance only)
                             db_ver_inc_map[db_ver] = d
@@ -207,6 +257,7 @@ if os.name == 'posix':
     # Test if the old bsddb is built-in
     static = 0
     try:
+        # Possibly already imported in the "warning" section (python 2.7)
         import bsddb
         if str(bsddb).find('built-in') >= 0:
             static = 1
@@ -267,7 +318,7 @@ elif os.name == 'nt':
             continue
         fullverstr = match.group(1)
         ver = fullverstr[0] + fullverstr[2]   # 31 == 3.1, 32 == 3.2, etc.
-    assert ver in ('41', '42', '43', '44', '45', '46', '47', '48'), (
+    assert (fullverstr[0], fullverstr[2]) in db_ver_list, (
         "pybsddb untested with this Berkeley DB version", ver)
     print('Detected Berkeley DB version', ver, 'from db.h')
 
@@ -359,7 +410,6 @@ pybsddb_doc/>`__ --
                     'Programming Language :: Python :: 2.6',
                     'Programming Language :: Python :: 2.7',
                     'Programming Language :: Python :: 3',
-                    'Programming Language :: Python :: 3.0',
                     'Programming Language :: Python :: 3.1',
                     'Programming Language :: Python :: 3.2',
                     ],
