@@ -118,6 +118,14 @@ Extreme (yet useful) examples:
     to make sure all tests still pass.
 """
 
+import warnings
+# Simulate "python -Wdefault".
+# http://docs.python.org/dev/library/warnings.html#updating-code-for-new-versions-of-python
+# Command line argument has priority, so the full matrix check can be more
+# strict.
+warnings.simplefilter('default')
+
+
 import gc
 import os
 import re
@@ -423,24 +431,9 @@ def runner(files, test_filter, debug):
             raise
 
 
-def remove_stale_bytecode(arg, dirname, names):
-    names = map(os.path.normcase, names)
-    for name in names:
-        if name.endswith(".pyc") or name.endswith(".pyo"):
-            srcname = name[:-1]
-            if srcname not in names:
-                fullname = os.path.join(dirname, name)
-                print "Removing stale bytecode file", fullname
-                os.unlink(fullname)
-
-
 def main(module_filter, test_filter):
     global pathinit
 
-    for root, dirs, files in os.walk(os.curdir) :
-        if len(files) :
-            remove_stale_bytecode(None, root, files)
-
     # Get the log.ini file from the current directory instead of possibly
     # buried in the build directory.  XXX This isn't perfect because if
     # log.ini specifies a log file, it'll be relative to the build directory.
